==> genArise_1.16.0.zip: genArise/doc/genArise.R <==
###################################################
### chunk number 1: 
###################################################
library(genArise)


###################################################
### chunk number 2: 
###################################################
data(Simon)
ls()


###################################################
### chunk number 3: 
###################################################
data(Simon)
datos <- attr(Simon, "spotData")
M <- log(datos$Cy3, 2) - log(datos$Cy5, 2)
imageLimma(M, 23, 24, 2, 2)


###################################################
### chunk number 4: 
###################################################
data(Simon)
datos <- attr(Simon, "spotData")
R <- log(datos$BgCy3, 2)
imageLimma(R, 23, 24, 2, 2, high = "red", low = "white")


###################################################
### chunk number 5: 
###################################################
data(Simon)
datos <- attr(Simon, "spotData")
G <- log(datos$BgCy5, 2)
imageLimma(G, 23, 24, 2, 2, low = "white", high = "green")


###################################################
### chunk number 6: 
###################################################
data(Simon)
ri.plot(Simon)


###################################################
### chunk number 7: 
###################################################
data(Simon)
ma.plot(Simon)


###################################################
### chunk number 8: 
###################################################
data(Simon)
cys.plot(Simon)


###################################################
### chunk number 9: 
###################################################
data(Simon)
c.spot <- bg.correct(Simon)
ri.plot(c.spot)


###################################################
### chunk number 10: 
###################################################
data(Simon)
n.spot <- grid.norm(mySpot = Simon, nr = 23, nc = 24)
ri.plot(n.spot)


###################################################
### chunk number 11: 
###################################################
data(Simon)
n.spot <- global.norm(mySpot = Simon)
ri.plot(n.spot)


###################################################
### chunk number 12: 
###################################################
data(Simon)
f.spot <- filter.spot(mySpot = Simon)
ri.plot(f.spot)


###################################################
### chunk number 13: 
###################################################
data(Simon)
u.spot <- spotUnique(mySpot = Simon)
ri.plot(u.spot)


###################################################
### chunk number 14: 
###################################################
data(Simon)
u.spot <- alter.unique(mySpot = Simon)
ri.plot(u.spot)


###################################################
### chunk number 15: 
###################################################
data(Simon)
u.spot <- meanUnique(mySpot = Simon)
ri.plot(u.spot)


###################################################
### chunk number 16: 
###################################################
data(WT.dataset)
Zscore.plot(WT.dataset, Zscore.min=1)

==> genArise_1.26.0.zip: genArise/doc/genArise.R <==
###################################################
### chunk number 1: 
###################################################
#line 44 "E:/biocbld/bbs-2.7-bioc/tmpdir/Rtmp2jt8gR/R.INSTALL47716514/genArise/inst/doc/genArise.Rnw"
library(genArise)


###################################################
### chunk number 2: 
###################################################
#line 66 "E:/biocbld/bbs-2.7-bioc/tmpdir/Rtmp2jt8gR/R.INSTALL47716514/genArise/inst/doc/genArise.Rnw"
data(Simon)
ls()


###################################################
### chunk number 3: 
###################################################
#line 84 "E:/biocbld/bbs-2.7-bioc/tmpdir/Rtmp2jt8gR/R.INSTALL47716514/genArise/inst/doc/genArise.Rnw"
data(Simon)
datos <- attr(Simon, "spotData")
M <- log(datos$Cy3, 2) - log(datos$Cy5, 2)
imageLimma(M, 23, 24, 2, 2)


###################################################
### chunk number 4: 
###################################################
#line 110 "E:/biocbld/bbs-2.7-bioc/tmpdir/Rtmp2jt8gR/R.INSTALL47716514/genArise/inst/doc/genArise.Rnw"
data(Simon)
datos <- attr(Simon, "spotData")
R <- log(datos$BgCy3, 2)
imageLimma(R, 23, 24, 2, 2, high = "red", low = "white")


###################################################
### chunk number 5: 
###################################################
#line 133 "E:/biocbld/bbs-2.7-bioc/tmpdir/Rtmp2jt8gR/R.INSTALL47716514/genArise/inst/doc/genArise.Rnw"
data(Simon)
datos <- attr(Simon, "spotData")
G <- log(datos$BgCy5, 2)
imageLimma(G, 23, 24, 2, 2, low = "white", high = "green")


###################################################
### chunk number 6: 
###################################################
#line 159 "E:/biocbld/bbs-2.7-bioc/tmpdir/Rtmp2jt8gR/R.INSTALL47716514/genArise/inst/doc/genArise.Rnw"
data(Simon)
ri.plot(Simon)


###################################################
### chunk number 7: 
###################################################
#line 175 "E:/biocbld/bbs-2.7-bioc/tmpdir/Rtmp2jt8gR/R.INSTALL47716514/genArise/inst/doc/genArise.Rnw"
data(Simon)
ma.plot(Simon)


###################################################
### chunk number 8: 
###################################################
#line 191 "E:/biocbld/bbs-2.7-bioc/tmpdir/Rtmp2jt8gR/R.INSTALL47716514/genArise/inst/doc/genArise.Rnw"
data(Simon)
cys.plot(Simon)


###################################################
### chunk number 9: 
###################################################
#line 216 "E:/biocbld/bbs-2.7-bioc/tmpdir/Rtmp2jt8gR/R.INSTALL47716514/genArise/inst/doc/genArise.Rnw"
data(Simon)
c.spot <- bg.correct(Simon)
ri.plot(c.spot)


###################################################
### chunk number 10: 
###################################################
#line 244 "E:/biocbld/bbs-2.7-bioc/tmpdir/Rtmp2jt8gR/R.INSTALL47716514/genArise/inst/doc/genArise.Rnw"
data(Simon)
n.spot <- grid.norm(mySpot = Simon, nr = 23, nc = 24)
ri.plot(n.spot)


###################################################
### chunk number 11: 
###################################################
#line 269 "E:/biocbld/bbs-2.7-bioc/tmpdir/Rtmp2jt8gR/R.INSTALL47716514/genArise/inst/doc/genArise.Rnw"
data(Simon)
n.spot <- global.norm(mySpot = Simon)
ri.plot(n.spot)


###################################################
### chunk number 12: 
###################################################
#line 297 "E:/biocbld/bbs-2.7-bioc/tmpdir/Rtmp2jt8gR/R.INSTALL47716514/genArise/inst/doc/genArise.Rnw"
data(Simon)
f.spot <- filter.spot(mySpot = Simon)
ri.plot(f.spot)


###################################################
### chunk number 13: 
###################################################
#line 323 "E:/biocbld/bbs-2.7-bioc/tmpdir/Rtmp2jt8gR/R.INSTALL47716514/genArise/inst/doc/genArise.Rnw"
data(Simon)
u.spot <- spotUnique(mySpot = Simon)
ri.plot(u.spot)


###################################################
### chunk number 14: 
###################################################
#line 346 "E:/biocbld/bbs-2.7-bioc/tmpdir/Rtmp2jt8gR/R.INSTALL47716514/genArise/inst/doc/genArise.Rnw"
data(Simon)
u.spot <- alter.unique(mySpot = Simon)
ri.plot(u.spot)


###################################################
### chunk number 15: 
###################################################
#line 369 "E:/biocbld/bbs-2.7-bioc/tmpdir/Rtmp2jt8gR/R.INSTALL47716514/genArise/inst/doc/genArise.Rnw"
data(Simon)
u.spot <- meanUnique(mySpot = Simon)
ri.plot(u.spot)


###################################################
### chunk number 16: 
###################################################
#line 424 "E:/biocbld/bbs-2.7-bioc/tmpdir/Rtmp2jt8gR/R.INSTALL47716514/genArise/inst/doc/genArise.Rnw"
data(WT.dataset)
Zscore.plot(WT.dataset, Zscore.min=1)
